#
# spec file for package python-agate-excel
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-agate-excel
Version:        0.4.1
Release:        1.3
Summary:        Read support for Excel files (xls and xlsx) for agate
License:        MIT
URL:            https://github.com/wireservice/agate-excel
Source:         https://github.com/wireservice/agate-excel/archive/%{version}.tar.gz
BuildRequires:  %{python_module agate >= 1.5.0}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module olefile}
BuildRequires:  %{python_module openpyxl >= 2.3.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module xlrd >= 0.9.4}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-agate >= 1.5.0
Requires:       python-numpy
Requires:       python-olefile
Requires:       python-openpyxl >= 2.3.0
Requires:       python-xlrd >= 0.9.4
BuildArch:      noarch
%python_subpackages

%description
Agate-excel adds read support for Excel files (xls and xlsx)
to agate.

%prep
%autosetup -p1 -n agate-excel-%{version}

sed -i -e '/^#!\//, 1d' agateexcel/*.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc AUTHORS.rst README.rst
%license COPYING
%{python_sitelib}/agateexcel*
%{python_sitelib}/agate_excel*

%changelog
* Sat Dec  2 2023 Dirk Müller <dmueller@suse.com>
- update to 0.4.1:
  * fix: :meth:`.Table.from_xlsx` no longer errors on unsized
    sheets.
  * The ``reset_dimensions`` argument to :meth:`.Table.from_xlsx`
    defaults to ``None`` instead of ``False``. If
    ``reset_dimensions`` is ``None``, and if the worksheet's
    dimensions are ``A1:A1``, recalculate the worksheet's
    dimensions. To disable this behavior, set
    ``reset_dimensions`` to ``False``.
  * If the ``reset_dimensions`` argument to
    :meth:`.Table.from_xlsx` is set, recalculate the worksheet's
    dimensions, instead of assuming that the table's width
    matches the first row's.
  * The ``reset_dimensions`` argument to :meth:`.Table.from_xlsx`
    is ignored if the ``read_only`` argument is false.
  * Add Python 3.8, 3.9, 3.10, 3.11, 3.12 support.
  * Drop support for 3.5 (2020-09-13), 3.6 (2021-12-23), 3.7
- drop python-agate-excel-no-python2.patch (upstream)
* Thu Mar  9 2023 pgajdos@suse.com
- do not require python-six
- added patches
  fix https://github.com/wireservice/agate-excel/commit/833dc6d39dda3e4b025e3e4dc61533622d65cc5f
  + python-agate-excel-no-python2.patch
* Fri Aug 13 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.2.5:
  * Add ``six`` to ``install_requires``.
  * Add ``row_limit`` keyword argument to ``from_xls`` and ``from_xlsx``. (#40)
  * Preserve column types from XLS files. (#36)
  * Add support for Compound File Binary File (CFBF) XLS files. (#44)
  * Close XLSX file before raising error for non-existent sheet. (#34)
  * Use less memory and close XLS files. (#39)
  * Drop support for Python 3.4 (end-of-life was March 18, 2019).
- Update {Build,}Requires.
* Thu Apr 16 2020 Matej Cepl <mcepl@suse.com>
- Switch from using nosetest runner to pytest
* Mon Dec  2 2019 Todd R <toddrme2178@gmail.com>
- Disable python2 support due to dependencies dropping python2
  support.
- Don't use setup.py test
* Wed Apr 17 2019 pgajdos@suse.com
- version update to 0.2.3
  * Fix bug in accepting ``column_names`` as keyword argument.
  * Add a ``reset_dimensions`` argument to :meth:`.Table.from_xlsx`
    to recalculate the data's dimensions, instead of trusting those
    in the file's properties.
  * Include tests and examples in distribution.
  * agate-excel is now tested against Python 3.6 and 3.7.
  * Drop support for Python 3.3 (end-of-life was September 29, 2017).
  * Add support for openpyxl 2.6.0.
- deleted patches
  - no-column.patch (upstreamed)
  - row-offset.patch (upstreamed)
* Wed Feb 27 2019 Tomáš Chvátal <tchvatal@suse.com>
- Switch to github tarball and enable tests
- Add patches from upstream git to pass the tests:
  * no-column.patch
  * row-offset.patch
* Wed May  9 2018 toddrme2178@gmail.com
- Update to version 0.2.2
  * Add an encoding_override argument to `.Table.from_xls` to
    override the encoding of the input XLS file.
  * Add a header argument to `.Table.from_xls` and
    `.Table.from_xlsx` to indicate the presence of a header row.
  * Add a read_only argument to `.Table.from_xlsx` to allo
    disabling read-only mode for some spreadsheets.
- Use license tag
* Fri Oct 20 2017 toddrme2178@gmail.com
- initial version
